@@ -81,6 +81,8 @@ struct BuilderContext
   gboolean        have_rofiles;
   gboolean        run_tests;
   gboolean        no_shallow_clone;
+  gboolean        opt_export_only;
+  char           *opt_mirror_screenshots_url;
 
   BuilderSdkConfig *sdk_config;
 };
@@ -344,6 +346,32 @@ builder_context_find_in_sources_dirs_va (BuilderContext *self,
   return NULL;
 }
 
+void
+builder_context_set_opt_export_only (BuilderContext *self,
+                                     gboolean       opt_export_only)
+{
+  self->opt_export_only = opt_export_only;
+}
+
+gboolean
+builder_context_get_opt_export_only (BuilderContext *self)
+{
+  return self->opt_export_only;
+}
+
+void
+builder_context_set_opt_mirror_screenshots_url (BuilderContext *self,
+                                                const char     *opt_mirror_screenshots_url)
+{
+  self->opt_mirror_screenshots_url = g_strdup(opt_mirror_screenshots_url);
+}
+
+const char *
+builder_context_get_opt_mirror_screenshots_url (BuilderContext *self)
+{
+  return self->opt_mirror_screenshots_url;
+}
+
 GFile *
 builder_context_find_in_sources_dirs (BuilderContext *self,
                                       ...)
@@ -377,6 +405,7 @@ builder_context_download_uri (BuilderContext *self,
                               const char     *url,
                               const char    **mirrors,
                               const char     *http_referer,
+                              gboolean        disable_http_decompression,
                               GFile          *dest,
                               const char     *checksums[BUILDER_CHECKSUMS_LEN],
                               GChecksumType   checksums_type[BUILDER_CHECKSUMS_LEN],
@@ -414,6 +443,7 @@ builder_context_download_uri (BuilderContext *self,
 
           if (builder_download_uri (mirror_uri,
                                     http_referer,
+                                    disable_http_decompression,
                                     dest,
                                     checksums, checksums_type,
                                     builder_context_get_curl_session (self),
@@ -427,6 +457,7 @@ builder_context_download_uri (BuilderContext *self,
 
   if (!builder_download_uri (original_uri,
                              http_referer,
+                             disable_http_decompression,
                              dest,
                              checksums, checksums_type,
                              builder_context_get_curl_session (self),
@@ -450,6 +481,7 @@ builder_context_download_uri (BuilderContext *self,
               g_print ("Trying mirror %s\n", mirrors[i]);
               if (!builder_download_uri (mirror_uri,
                                          http_referer,
+                                         disable_http_decompression,
                                          dest,
                                          checksums, checksums_type,
                                          builder_context_get_curl_session (self),
