@@ -1154,6 +1154,8 @@ flatpak_create_curl_session (const char *user_agent)
   curl_easy_setopt (curl_session, CURLOPT_FOLLOWLOCATION, 1);
   curl_easy_setopt (curl_session, CURLOPT_MAXREDIRS, 50);
   curl_easy_setopt (curl_session, CURLOPT_NOPROGRESS, 0);
+  curl_easy_setopt (curl_session, CURLOPT_LOW_SPEED_TIME, 60L);
+  curl_easy_setopt (curl_session, CURLOPT_LOW_SPEED_LIMIT, 10000L);
   curl_easy_setopt (curl_session, CURLOPT_USERAGENT, user_agent);
 
   return curl_session;
