@@ -1775,6 +1775,12 @@ builder_module_build_helper (BuilderModule  *self,
       prefix = builder_options_get_prefix (self->build_options, context);
       libdir = builder_options_get_libdir (self->build_options, context);
 
+      if (meson)
+	{
+	  /* Meson's setup command is now meson setup */
+          g_ptr_array_add (configure_args_arr, g_strdup ("setup"));
+	}
+
       if (cmake || cmake_ninja)
         {
           g_ptr_array_add (configure_args_arr, g_strdup_printf ("-DCMAKE_INSTALL_PREFIX:PATH='%s'", prefix));
@@ -1947,7 +1953,7 @@ builder_module_build_helper (BuilderModule  *self,
       if (make_cmd && test_arg && *test_arg != 0)
         {
           if (!build (app_dir, self->name, context, source_dir, build_dir_relative, test_args, env, error,
-                      make_cmd, test_arg, NULL))
+                      make_cmd, test_arg, make_j ? make_j : skip_arg, NULL))
             {
               g_prefix_error (error, "Running %s %s failed: ", make_cmd, test_arg);
               return FALSE;
